@@ -4,9 +4,6 @@ require 'json-schema'
 test_name "Running facter --json should validate against the schema"
 
 agents.each do |agent|
-  step "Agent #{agent}: Install json gem (needed on older platforms)"
-  on(agent, "gem install json") unless agent['platform'] =~ /windows/
-
   step "Agent #{agent}: run 'facter --json' and validate"
   on(agent, facter('--json')) do
     schema = JSON.parse(File.read("../schema/facter.json"))
