@@ -1,8 +1,60 @@
 # Fact: selinux
 #
 # Purpose:
+#   Determine whether SE Linux is enabled on the node.
 #
 # Resolution:
+#   Checks for the existence of the enforce file under the SE Linux mount
+#   point (e.g. `/selinux/enforce`) and returns true if `/proc/self/attr/current`
+#   does not contain the kernel.
+#
+# Caveats:
+#
+
+# Fact: selinux_config_mode
+#
+# Purpose:
+#   Returns the configured SE Linux mode (e.g., `enforcing`, `permissive`, or `disabled`).
+#
+# Resolution:
+#   Parses the output of `sestatus_cmd` and returns the value of the line beginning
+#   with `Mode from config file:`.
+#
+# Caveats:
+#
+
+# Fact: selinux_config_policy
+#
+# Purpose:
+#   Returns the configured SE Linux policy (e.g., `targeted`, `MLS`, or `minimum`).
+#
+# Resolution:
+#   Parses the output of `sestatus_cmd` and returns the value of the line beginning
+#   with `Policy from config file:`.
+#
+# Caveats:
+#
+
+# Fact: selinux_enforced
+#
+# Purpose:
+#   Returns whether SE Linux is enabled (`true`) or not (`false`).
+#
+# Resolution:
+#   Returns the value found in the `enforce` file under the SE Linux mount
+#   point (e.g. `/selinux/enforce`).
+#
+# Caveats:
+#
+
+# Fact: selinux_policyversion
+#
+# Purpose:
+#   Returns the current SE Linux policy version.
+#
+# Resolution:
+#   Reads the content of the `policyvers` file found under the SE Linux mount point,
+#   e.g. `/selinux/policyvers`.
 #
 # Caveats:
 #
@@ -22,7 +74,7 @@ def selinux_mount_point
     # a hang. Reading from other parts of /proc does not seem to cause this problem.
     # The work around is to read the file in another process.
     # -- andy Fri Aug 31 2012
-    selinux_line = Facter::Util::Resolution.exec('cat /proc/self/mounts').lines.find { |line| line =~ /selinuxfs/ }
+    selinux_line = Facter::Core::Execution.exec('cat /proc/self/mounts').each_line.find { |line| line =~ /selinuxfs/ }
     if selinux_line
       path = selinux_line.split[1]
     end
@@ -36,8 +88,11 @@ Facter.add("selinux") do
     result = "false"
     if FileTest.exists?("#{selinux_mount_point}/enforce")
       if FileTest.exists?("/proc/self/attr/current")
-        if (File.read("/proc/self/attr/current") != "kernel\0")
-          result = "true"
+        begin
+          if (File.read("/proc/self/attr/current") != "kernel\0")
+            result = "true"
+          end
+        rescue
         end
       end
     end
@@ -72,7 +127,7 @@ Facter.add("selinux_current_mode") do
   confine :selinux => :true
   setcode do
     result = 'unknown'
-    mode = Facter::Util::Resolution.exec(sestatus_cmd)
+    mode = Facter::Core::Execution.exec(sestatus_cmd)
     mode.each_line { |l| result = $1 if l =~ /^Current mode\:\s+(\w+)$/i }
     result.chomp
   end
@@ -82,7 +137,7 @@ Facter.add("selinux_config_mode") do
   confine :selinux => :true
   setcode do
     result = 'unknown'
-    mode = Facter::Util::Resolution.exec(sestatus_cmd)
+    mode = Facter::Core::Execution.exec(sestatus_cmd)
     mode.each_line { |l| result = $1 if l =~ /^Mode from config file\:\s+(\w+)$/i }
     result.chomp
   end
@@ -92,19 +147,8 @@ Facter.add("selinux_config_policy") do
   confine :selinux => :true
   setcode do
     result = 'unknown'
-    mode = Facter::Util::Resolution.exec(sestatus_cmd)
+    mode = Facter::Core::Execution.exec(sestatus_cmd)
     mode.each_line { |l| result = $1 if l =~ /^Policy from config file\:\s+(\w+)$/i }
     result.chomp
   end
 end
-
-# This is a legacy fact which returns the old selinux_mode fact value to prevent
-# breakages of existing manifests. It should be removed at the next major release.
-# See ticket #6677.
-
-Facter.add("selinux_mode") do
-  confine :selinux => :true
-  setcode do
-    Facter.value(:selinux_config_policy)
-  end
-end
