@@ -62,6 +62,10 @@ class Facter::Util::Resolution
     @weight = nil
   end
 
+  def resolution_type
+    :simple
+  end
+
   # Evaluate the given block in the context of this resolution. If a block has
   # already been evaluated emit a warning to that effect.
   #
@@ -128,7 +132,7 @@ class Facter::Util::Resolution
   def setcode(string = nil, &block)
     if string
       @code = Proc.new do
-        output = Facter::Core::Execution.exec(string, :on_fail => nil)
+        output = Facter::Core::Execution.execute(string, :on_fail => nil)
         if output.nil? or output.empty?
           nil
         else
